[cmake-developers] [CMake 0012592]: New componentwise extra install commands for NSIS-generator

2011-11-26 Thread Mantis Bug Tracker

The following issue has been SUBMITTED. 
== 
http://public.kitware.com/Bug/view.php?id=12592 
== 
Reported By:Marcel
Assigned To:
== 
Project:CMake
Issue ID:   12592
Category:   CPack
Reproducibility:N/A
Severity:   feature
Priority:   low
Status: new
== 
Date Submitted: 2011-11-26 14:49 EST
Last Modified:  2011-11-26 14:49 EST
== 
Summary:New componentwise extra install commands for
NSIS-generator
Description: 
The attached patch adds the following functionality to the NSIS-generator.

NSIS commands given to the new CPack option
CPACK_COMPONENT_name_EXTRA_INSTALL_COMMANDS are added exclusively to the
install section generated for the component name.

This gives greater flexibility in contrast to
CPACK_NSIS_EXTRA_INSTALL_COMMANDS that only allows to add NSIS commands to
the overall install section. With the new CPack option NSIS code can be added
that is only executed if the user chooses to install the corresponding section. 

Also the constraint that only components with files are added
to the generated NSIS-script is removed, so that components with extra install
commands only can be created.
== 

Issue History 
Date ModifiedUsername   FieldChange   
== 
2011-11-26 14:49 Marcel New Issue
2011-11-26 14:49 Marcel File Added:
0001-CPack-Added-EXTRA_INSTALL_COMMANDS-option-for-single.patch 
  
==

--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


[cmake-developers] [CMake 0012593]: CMAKE_C_COMPILER cannot contain command line arguments

2011-11-26 Thread Mantis Bug Tracker

The following issue has been SUBMITTED. 
== 
http://public.kitware.com/Bug/view.php?id=12593 
== 
Reported By:Stefan Majewsky
Assigned To:
== 
Project:CMake
Issue ID:   12593
Category:   CMake
Reproducibility:always
Severity:   minor
Priority:   normal
Status: new
== 
Date Submitted: 2011-11-26 16:09 EST
Last Modified:  2011-11-26 16:09 EST
== 
Summary:CMAKE_C_COMPILER cannot contain command line
arguments
Description: 
The summary looks like I want CMAKE_C_FLAGS, but no! My usecase is linking
something against dietlibc (http://www.fefe.de/dietlibc/ for reference). The
documentation for dietlibc suggests that I shall use the diet command for
compiling. That command takes a gcc command line, e.g.

diet gcc -o test test.c

diet has its own bunch of options, e.g.

diet -Os -v gcc -o test test.c

I tried to use diet in CMake via

set(CMAKE_C_COMPILER diet gcc)

but that outputs diet gcc into the Makefile verbatim (with the quotes!), and
of course make then complains that the command diet gcc does not exist. When
the quotes are omitted in CMakeLists.txt, the command in the Makefile becomes
diet;gcc.

My current workaround is to

set(CMAKE_C_COMPILER ${PROJECT_SOURCE_DIR}/invoke-compiler.sh)

where that shell script calls diet gcc $@, but I'd prefer a proper solution.


== 

Issue History 
Date ModifiedUsername   FieldChange   
== 
2011-11-26 16:09 Stefan MajewskyNew Issue
==

--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-developers


Re: [CMake] Build doesn't work with Mac OS X Lion...

2011-11-26 Thread Daniel Dekkers
This:

SET(CMAKE_OSX_ARCHITECTURES $(ARCHS_STANDARD_32_BIT))
seems to result in a standard Xcode setting (armv7 (standard)) which is also 
set when you let Xcode create a fresh iOS app (from its own templates).

But you also see this a lot on the fora:
SET(CMAKE_OSX_ARCHITECTURES $(ARCHS_UNIVERSAL_IPHONE_OS))

Not sure.

On Nov 26, 2011, at 4:38 AM, Michael Jackson wrote:

 There is a cmake variable that you set during  onfiguration time.
 Something like os_x_architectures. There you can add the specific arch
 that you want to build for.
 
 -
 Mike Jackson www.bluequartz.net
 Principal Software Engineer   mike.jack...@bluequartz.net
 BlueQuartz Software   Dayton, Ohio
 
 Sent from my mobile device. Please excuse the shortness of the reply.
 
 On Nov 25, 2011, at 14:47, Dick Munroe mun...@csworks.com wrote:
 
 I've got a build that works just fine with Leopard.
 
 For reasons I won't get into, I had to upgrade one of my systems to Lion and 
 now (I've installed XCode 4.2) the build won't work.  I get the following 
 error:
 
 [  0%] Reaping winning child 0x10260c510 PID 1009
 Live child 0x10260c510 
 (libxp/CMakeFiles/xp.dir/Users/munroe/Documents/My_SVN/ESPlanner_Computation_Engine.U2011-11-01/Common/xmllib/print/libxp.cpp.o)
  PID 1010
 Building CXX object 
 libxp/CMakeFiles/xp.dir/Users/munroe/Documents/My_SVN/ESPlanner_Computation_Engine.U2011-11-01/Common/xmllib/print/libxp.cpp.o
 Reaping winning child 0x10260c510 PID 1010
 Live child 0x10260c510 
 (libxp/CMakeFiles/xp.dir/Users/munroe/Documents/My_SVN/ESPlanner_Computation_Engine.U2011-11-01/Common/xmllib/print/libxp.cpp.o)
  PID 1011
 llvm-g++-4.2: Invalid arch name : -O2
 Reaping losing child 0x10260c510 PID 1011
 make[2]: *** 
 [libxp/CMakeFiles/xp.dir/Users/munroe/Documents/My_SVN/ESPlanner_Computation_Engine.U2011-11-01/Common/xmllib/print/libxp.cpp.o]
  Error 1
 Removing child 0x10260c510 PID 1011 from chain.
 Reaping losing child 0x10c20c290 PID 1008
 make[1]: *** [libxp/CMakeFiles/xp.dir/all] Error 2
 Removing child 0x10c20c290 PID 1008 from chain.
 Reaping losing child 0x10940e730 PID 996
 
 If I dig around, I find the CXX flags to be:
 
 -arch  -O2 -fPIC
 
 and for some reason the Lion g++ compiler is choking thinking that there 
 should be and arch value.  Which if I dig around in the Leopard build I find:
 
 -Dxp_EXPORTS  -arch i386 -O2 -g -fPIC
 
 Which brings up the questions, (1) with the same CMakeLists.txt file, why am 
 I getting different values and (2) how do I get the arch to be i386 on the 
 Lion build.
 
 Best,
 
 Dick Munroe
 
 --
 
 Powered by www.kitware.com
 
 Visit other Kitware open-source projects at 
 http://www.kitware.com/opensource/opensource.html
 
 Please keep messages on-topic and check the CMake FAQ at: 
 http://www.cmake.org/Wiki/CMake_FAQ
 
 Follow this link to subscribe/unsubscribe:
 http://www.cmake.org/mailman/listinfo/cmake
 --
 
 Powered by www.kitware.com
 
 Visit other Kitware open-source projects at 
 http://www.kitware.com/opensource/opensource.html
 
 Please keep messages on-topic and check the CMake FAQ at: 
 http://www.cmake.org/Wiki/CMake_FAQ
 
 Follow this link to subscribe/unsubscribe:
 http://www.cmake.org/mailman/listinfo/cmake

--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] [CPACK] Patch with componentwise extra install commands for NSIS-generator

2011-11-26 Thread Marcel

Hi,

I extended cpack's NSIS-generator and want to contribute the attached patch.

It adds the CPACK_COMPONENT_name_EXTRA_INSTALL_COMMANDS option to 
cpack that allows to add NSIS commands exclusivly to the install section 
generated for the component name. So it adopts the option 
CPACK_NSIS_EXTRA_INSTALL_COMMANDS for single components/sections.


That way special code can be added to a section that ist only executed 
if the user chooses to install the section.


Perhaps this change could be merged into the cmake, because I think this 
could be of some use for other cpack users.


If this is not the right place to contribute, could someone please give 
me a pointer.


Best regards,

Marcel

From 88dcca63c40aaa25902023a3b7c7ae8e9f9c44c2 Mon Sep 17 00:00:00 2001
From: Marcel minusdre...@gmail.com
Date: Mon, 14 Nov 2011 15:13:49 +0100
Subject: [PATCH] CPack: Added EXTRA_INSTALL_COMMANDS option for single
 COMPONENTs to NSIS-Generator. NSIS commands given to
 CPACK_COMPONENT_name_EXTRA_INSTALL_COMMANDS are added
 exclusivly to the install section generated for the
 component name.

This gives greater flexibility in contrast to
CPACK_NSIS_EXTRA_INSTALL_COMMANDS that only allows to add NSIS commands to
the overall install section, in case that extra commands should only be
executed if the user chooses to install a certain section.

Also, removed the constraint that only components with files are added
to the generated NSIS-Script, so that components with extra install
commands only can be created.

BUFIX: check for empty extraInstallCommands.
---
 Source/CPack/cmCPackComponentGroup.h  |3 +++
 Source/CPack/cmCPackGenerator.cxx |   20 
 Source/CPack/cmCPackNSISGenerator.cxx |   31 +++
 3 files changed, 50 insertions(+), 4 deletions(-)

diff --git a/Source/CPack/cmCPackComponentGroup.h 
b/Source/CPack/cmCPackComponentGroup.h
index cebdd6d..af81fc2 100644
--- a/Source/CPack/cmCPackComponentGroup.h
+++ b/Source/CPack/cmCPackComponentGroup.h
@@ -89,6 +89,9 @@ public:
   /// The list of installed directories that are part of this component.
   std::vectorstd::string Directories;
 
+  /// Extra install commands that are added to this section
+  std::vectorstd::string ExtraInstallCommands;
+
   /// Get the total installed size of all of the files in this
   /// component, in bytes. installDir is the directory into which the 
   /// component was installed.
diff --git a/Source/CPack/cmCPackGenerator.cxx 
b/Source/CPack/cmCPackGenerator.cxx
index 083279f..e086c26 100644
--- a/Source/CPack/cmCPackGenerator.cxx
+++ b/Source/CPack/cmCPackGenerator.cxx
@@ -1520,6 +1520,26 @@ cmCPackGenerator::GetComponent(const char *projectName, 
const char *name)
   component-Description = description;
   }
 
+// Process extra install commands
+const char* extraInstallCommands
+  = this-GetOption((macroPrefix + _EXTRA_INSTALL_COMMANDS).c_str());
+if (extraInstallCommands != NULL)
+  {
+  std::vectorstd::string eCommandsVector;
+  cmSystemTools::ExpandListArgument(extraInstallCommands, eCommandsVector);
+  std::vectorstd::string::iterator eCommIt;
+  for (eCommIt = eCommandsVector.begin();
+  eCommIt != eCommandsVector.end();
+  ++eCommIt)
+{
+  if (!eCommIt-empty())
+{
+  component-ExtraInstallCommands.push_back(*eCommIt);
+}
+}
+  }
+
+
 // Determine the installation types.
 const char *installTypes 
   = this-GetOption((macroPrefix + _INSTALL_TYPES).c_str());
diff --git a/Source/CPack/cmCPackNSISGenerator.cxx 
b/Source/CPack/cmCPackNSISGenerator.cxx
index 2b94067..e5e49ca 100644
--- a/Source/CPack/cmCPackNSISGenerator.cxx
+++ b/Source/CPack/cmCPackNSISGenerator.cxx
@@ -242,7 +242,10 @@ int cmCPackNSISGenerator::PackageFiles()
   if (compIt-second.Files.empty())
 {
 // NSIS cannot cope with components that have no files.
-continue;
+   if (compIt-second.ExtraInstallCommands.empty())
+ {
+ continue;
+ }
 }
 
   anyDownloadedComponents =
@@ -819,8 +822,18 @@ CreateComponentDescription(cmCPackComponent *component,
 }
   else
 {
-componentCode +=   File /r \${INST_DIR}\\ +
-  component-Name + \\*.*\\n;
+  if (!component-Files.empty())
+{
+componentCode +=   File /r \${INST_DIR}\\ +
+component-Name + \\*.*\\n;
+}
+}
+  std::vectorstd::string::iterator extraIt;
+  for (extraIt = component-ExtraInstallCommands.begin();
+   extraIt != component-ExtraInstallCommands.end();
+   extraIt++)
+{
+componentCode +=+ *extraIt + \n;
 }
   componentCode += SectionEnd\n;
 
@@ -972,9 +985,19 @@ CreateComponentGroupDescription(cmCPackComponentGroup 
*group,
comp != group-Components.end(); 
++comp)
 {
+
 if ((*comp)-Files.empty())
   {
-  continue;
+  if 

Re: [CMake] parallel build using cmake --build?

2011-11-26 Thread Michael Hertling
On 11/26/2011 04:16 AM, Steve M. Robbins wrote:
 Hi,
 
 To build VTK on our windows build server, I wrote a small batch script
 that invokes cmake --build.
 
 My developer machine is multicore; is there a way to get cmake --build 
 to run multiple jobs?
 
 Thanks,
 -Steve

cmake --build is just a front-end for the native build tool CMake
generates input for. If this tool can be invoked via the command line
with options for parallel building, you can provide them after the --
in the cmake --build command, e.g. cmake --build bindir -- -j 4
for parallel building with Makefiles.

Regards,

Michael
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] parallel build using cmake --build?

2011-11-26 Thread John Drescher
On Fri, Nov 25, 2011 at 10:16 PM, Steve M. Robbins st...@sumost.ca wrote:
 Hi,

 To build VTK on our windows build server, I wrote a small batch script
 that invokes cmake --build.

 My developer machine is multicore; is there a way to get cmake --build
 to run multiple jobs?


On windows, I use the following tool

http://www.codeproject.com/KB/cpp/runjobs.aspx

to build each configuration (Debug, Release, RelWithDebInfo ...) in
parallel using separate calls to cmake --build.

John
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] add_test WORKING_DIRECTORY

2011-11-26 Thread David Cole
You are calling add_test correctly.

Now you need to call ctest like this:

  ctest -C Release
or
  ctest -C Debug

to test a particular configuration...


HTH,
David


On Fri, Nov 25, 2011 at 11:21 AM, W Eryk Wolski wewol...@gmail.com wrote:
 I am testing against reference data in the source directory.
 However, I would like to perform out of source builds.


 With
 add_test(SpoofTest ${BinOut}/SpoofTest )
 the test dont find's the data, because the data path is hard coded in the
 tests and the build directory location is arbitrary.


 My Idea is to use the WORKING_DIRECTORY option to execute the tests in the
 Source directory.

 add_test(NAME SpoofTest
 WORKING_DIRECTORY ${CMAKE_SOURCE_DIR}
 COMMAND ${BinOut}/SpoofTest)

 However, I do not understand the COMMAND parameter.

 This is what I am getting when I run ctest:
 Checking test dependency graph end
 test 1
     Start 1: SpoofTest

 1: Test command: NOT_AVAILABLE
 Test not available without configuration.  (Missing -C config?)
 1/1 Test #1: SpoofTest ***Not Run   0.00 sec

 0% tests passed, 1 tests failed out of 1

 Total Test time (real) =   2.29 sec

 The following tests FAILED:
   1 - SpoofTest (Not Run)
 Errors while running CTest

 Can anyone please explain the COMMAND parameter to me!

 Regards
 Eryk







 --
 Witold Eryk Wolski

 Heidmark str 5
 D-28329 Bremen
 tel.: 04215261837

 --

 Powered by www.kitware.com

 Visit other Kitware open-source projects at
 http://www.kitware.com/opensource/opensource.html

 Please keep messages on-topic and check the CMake FAQ at:
 http://www.cmake.org/Wiki/CMake_FAQ

 Follow this link to subscribe/unsubscribe:
 http://www.cmake.org/mailman/listinfo/cmake

--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] iOS Archiving (Xcode 4.2, Lion, CMake2.8-6)

2011-11-26 Thread David Cole
Really?
The only error output is:

  Command /Developer/Platforms/iPhoneOS.platform/Developer/usr/bin/clang++
failed with exit code 1

?? How are we supposed to figure out what's wrong with the
archiving step with that?

What are the Xcode project file differences between a CMake-generated
project that demonstrates this problem, and an Xcode generated project
that does not...? Can you reduce it down to a simplest case that's
easy to analyze?


Thx,
David


On Fri, Nov 25, 2011 at 12:30 PM, Daniel Dekkers d.dekk...@cthrough.nl wrote:
 Hi,

 Has anyone managed to perform a successful iOS Archiving pass yet?

 Our apps run on the simulator (both iPhone (5.0) and iPad (5.0)) and on the 
 actual devices iPhone 3GS (5.0.1) and iPad2 (5.0.1), but archiving always 
 gives a link error:

 Ld 
 /Users/danieldekkers/Library/Developer/Xcode/DerivedData/All-fgyaqwkvsryjkhbiepprnmdcager/ArchiveIntermediates/Discs/InstallationBuildProductsLocation/Application/Discs.app/Discs
  normal armv7
    cd /Users/danieldekkers/development
    setenv IPHONEOS_DEPLOYMENT_TARGET 4.3
    setenv PATH 
 /Developer/Platforms/iPhoneOS.platform/Developer/usr/bin:/Developer/usr/bin:/usr/bin:/bin:/usr/sbin:/sbin
    /Developer/Platforms/iPhoneOS.platform/Developer/usr/bin/clang++ -arch 
 armv7 -isysroot 
 /Developer/Platforms/iPhoneOS.platform/Developer/SDKs/iPhoneOS5.0.sdk 
 -L/Users/danieldekkers/Library/Developer/Xcode/DerivedData/All-fgyaqwkvsryjkhbiepprnmdcager/ArchiveIntermediates/Discs/BuildProductsPath/Release-iphoneos
  
 -F/Users/danieldekkers/Library/Developer/Xcode/DerivedData/All-fgyaqwkvsryjkhbiepprnmdcager/ArchiveIntermediates/Discs/BuildProductsPath/Release-iphoneos
  -filelist 
 /Users/danieldekkers/Library/Developer/Xcode/DerivedData/All-fgyaqwkvsryjkhbiepprnmdcager/ArchiveIntermediates/Discs/IntermediateBuildFilesPath/All.build/Release-iphoneos/Discs.build/Objects-normal/armv7/Discs.LinkFileList
  -dead_strip -ObjC -framework OpenGLES -framework UIKit -framework Foundation 
 -framework CoreGraphics -framework QuartzCore -framework CoreData -framework 
 Coremotion -Wl,-search_paths_first -Wl,-headerpad_max_install_names 
 /Users/danieldekkers/development/build/iOS/ES1/rendertools/src/Rel
  ease-iphoneos/libRenderTools.a -lz -miphoneos-version-min=4.3 -o 
 /Users/danieldekkers/Library/Developer/Xcode/DerivedData/All-fgyaqwkvsryjkhbiepprnmdcager/ArchiveIntermediates/Discs/InstallationBuildProductsLocation/Application/Discs.app/Discs
 Command /Developer/Platforms/iPhoneOS.platform/Developer/usr/bin/clang++ 
 failed with exit code 1

 This is a problem, because you have to archive an ipa file, AdHoc or AppStore 
 to ship your application.

 These are our IOS specific settings at the moment, lots of trial-and-error, 
 but at least they work on the simulator and attached devices:

 IF( RT_IOS )
        # Toolchain settings can (for the time being) just be included...
        SET (CMAKE_SYSTEM_NAME Generic)
        SET (CMAKE_SYSTEM_VERSION 1)
        SET (CMAKE_SYSTEM_PROCESSOR arm)

        SET (RT_SDKVER 5.0 CACHE PATH iOS SDK version )
        SET (DEVROOT /Developer/Platforms/iPhoneOS.platform/Developer)
        SET (SDKROOT ${DEVROOT}/SDKs/iPhoneOS${RT_SDKVER}.sdk)
        IF( EXISTS ${SDKROOT} )
                SET (CMAKE_OSX_SYSROOT ${SDKROOT})
        ELSE()
                MESSAGE( Warning, iOS SDK path not found:  ${SDKROOT})
        ENDIF()
        SET (CMAKE_OSX_ARCHITECTURES $(ARCHS_UNIVERSAL_IPHONE_OS)) # Either 
 $(ARCHS_UNIVERSAL_IPHONE_OS) or arm6 arm7

        # SET (CMAKE_C_COMPILER ${DEVROOT}/usr/bin/gcc)      # Can be 
 removed, just let Xcode choose the default.
        # SET (CMAKE_CXX_COMPILER ${DEVROOT}/usr/bin/g++)    # Can be 
 removed, just let Xcode choose the default.

        SET (CMAKE_FIND_ROOT_PATH ${DEVELOPMENT_ROOT} ${SDKROOT} 
 ${DEVROOT})
        SET (CMAKE_FIND_ROOT_PATH_MODE_PROGRAM BOTH)
        SET (CMAKE_FIND_ROOT_PATH_MODE_LIBRARY ONLY)
        SET (CMAKE_FIND_ROOT_PATH_MODE_INCLUDE ONLY)

        SET( RT_DEPLOYMENT_TARGET 4.3 CACHE STRING minimum required SDK )

        SET( GCC_INPUT_FILETYPE Objective-C++ )
        SET( CMAKE_CXX_FLAGS -x objective-c++ -mno-thumb )

        # For iOS builds this is needed for the app to initiate the 
 UIApplication delegate instance...
        SET( CMAKE_EXE_LINKER_FLAGS ${CMAKE_EXE_LINKER_FLAGS} -ObjC )

        # Look in the correct build directories when linking the app to the 
 RenderTools library...
        SET( CMAKE_XCODE_EFFECTIVE_PLATFORMS -iphoneos;-iphonesimulator )
 ENDIF()

 Just wondering if someone is following the same path.

 Thanks,

 Daniel
 --

 Powered by www.kitware.com

 Visit other Kitware open-source projects at 
 http://www.kitware.com/opensource/opensource.html

 Please keep messages on-topic and check the CMake FAQ at: 
 http://www.cmake.org/Wiki/CMake_FAQ

 Follow this link to subscribe/unsubscribe:
 http://www.cmake.org/mailman/listinfo/cmake

--

Powered by www.kitware.com

Visit other Kitware open-source 

Re: [CMake] Build doesn't work with Mac OS X Lion...

2011-11-26 Thread David Cole
Are you using CMake 2.8.6...? Older CMake versions have not been used
much on Lion. It wouldn't surprise me if 2.8.6 works, but earlier
versions have issues...


HTH,
David


On Sat, Nov 26, 2011 at 6:37 AM, Daniel Dekkers d.dekk...@cthrough.nl wrote:
 This:

 SET(CMAKE_OSX_ARCHITECTURES $(ARCHS_STANDARD_32_BIT))
 seems to result in a standard Xcode setting (armv7 (standard)) which is 
 also set when you let Xcode create a fresh iOS app (from its own templates).

 But you also see this a lot on the fora:
 SET(CMAKE_OSX_ARCHITECTURES $(ARCHS_UNIVERSAL_IPHONE_OS))

 Not sure.

 On Nov 26, 2011, at 4:38 AM, Michael Jackson wrote:

 There is a cmake variable that you set during  onfiguration time.
 Something like os_x_architectures. There you can add the specific arch
 that you want to build for.

 -
 Mike Jackson                     www.bluequartz.net
 Principal Software Engineer       mike.jack...@bluequartz.net
 BlueQuartz Software               Dayton, Ohio
 
 Sent from my mobile device. Please excuse the shortness of the reply.

 On Nov 25, 2011, at 14:47, Dick Munroe mun...@csworks.com wrote:

 I've got a build that works just fine with Leopard.

 For reasons I won't get into, I had to upgrade one of my systems to Lion 
 and now (I've installed XCode 4.2) the build won't work.  I get the 
 following error:

 [  0%] Reaping winning child 0x10260c510 PID 1009
 Live child 0x10260c510 
 (libxp/CMakeFiles/xp.dir/Users/munroe/Documents/My_SVN/ESPlanner_Computation_Engine.U2011-11-01/Common/xmllib/print/libxp.cpp.o)
  PID 1010
 Building CXX object 
 libxp/CMakeFiles/xp.dir/Users/munroe/Documents/My_SVN/ESPlanner_Computation_Engine.U2011-11-01/Common/xmllib/print/libxp.cpp.o
 Reaping winning child 0x10260c510 PID 1010
 Live child 0x10260c510 
 (libxp/CMakeFiles/xp.dir/Users/munroe/Documents/My_SVN/ESPlanner_Computation_Engine.U2011-11-01/Common/xmllib/print/libxp.cpp.o)
  PID 1011
 llvm-g++-4.2: Invalid arch name : -O2
 Reaping losing child 0x10260c510 PID 1011
 make[2]: *** 
 [libxp/CMakeFiles/xp.dir/Users/munroe/Documents/My_SVN/ESPlanner_Computation_Engine.U2011-11-01/Common/xmllib/print/libxp.cpp.o]
  Error 1
 Removing child 0x10260c510 PID 1011 from chain.
 Reaping losing child 0x10c20c290 PID 1008
 make[1]: *** [libxp/CMakeFiles/xp.dir/all] Error 2
 Removing child 0x10c20c290 PID 1008 from chain.
 Reaping losing child 0x10940e730 PID 996

 If I dig around, I find the CXX flags to be:

 -arch  -O2 -fPIC

 and for some reason the Lion g++ compiler is choking thinking that there 
 should be and arch value.  Which if I dig around in the Leopard build I 
 find:

 -Dxp_EXPORTS  -arch i386 -O2 -g -fPIC

 Which brings up the questions, (1) with the same CMakeLists.txt file, why 
 am I getting different values and (2) how do I get the arch to be i386 on 
 the Lion build.

 Best,

 Dick Munroe

 --

 Powered by www.kitware.com

 Visit other Kitware open-source projects at 
 http://www.kitware.com/opensource/opensource.html

 Please keep messages on-topic and check the CMake FAQ at: 
 http://www.cmake.org/Wiki/CMake_FAQ

 Follow this link to subscribe/unsubscribe:
 http://www.cmake.org/mailman/listinfo/cmake
 --

 Powered by www.kitware.com

 Visit other Kitware open-source projects at 
 http://www.kitware.com/opensource/opensource.html

 Please keep messages on-topic and check the CMake FAQ at: 
 http://www.cmake.org/Wiki/CMake_FAQ

 Follow this link to subscribe/unsubscribe:
 http://www.cmake.org/mailman/listinfo/cmake

 --

 Powered by www.kitware.com

 Visit other Kitware open-source projects at 
 http://www.kitware.com/opensource/opensource.html

 Please keep messages on-topic and check the CMake FAQ at: 
 http://www.cmake.org/Wiki/CMake_FAQ

 Follow this link to subscribe/unsubscribe:
 http://www.cmake.org/mailman/listinfo/cmake

--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[CMake] BUILD_COMMAND having a hard time getting usable command lines

2011-11-26 Thread J Decker
Earlier I wondered if there was a way to stop recusive invocation of a
build command in a cmake script - I found something like a solution;
when I run the command, set an environment variable and don't run the
command if that environment variable is set... But...

If I specify 'TARGET' in BUILD_COMMAND, then it gets extra quotes
around it, which make it impossible to pass to execute_process.  Also
why doesn't cmake-gui run certain commands?

--example - probably incomplete ---

PROJECT( whatever )
  build_command( GENERATOR_BUILD_COMMAND CONFIGURATION
${CMAKE_BUILD_TYPE} PROJECT_NAME ${PROJECT_NAME} TARGET all )
  message( build command:${GENERATOR_BUILD_COMMAND} )

- output  ---

build command:e:/tools/unix/mingw/bin/mingw32-make.exe -i all
mingw32-make.exe: *** No rule to make target `all'.  Stop.

---end output, begin explanation

In order to get BUILD_COMMAND output to work at all I have to

STRING( REPLACE \  ; GENERATOR_BUILD_COMMAND
${GENERATOR_BUILD_COMMAND} )

which replaces the spaces in the command with semicolons, so it looks
like seperate commands for

  EXECUTE_PROCESS(COMMAND ${GENERATOR_BUILD_COMMAND}
WORKING_DIRECTORY ${CMAKE_BINARY_DIR} )

 and in cmake-gui the output looks something like

---
build command:e:/tools/unix/mingw/bin/mingw32-make.exe -i all
Executing command... (output just before Execute_process)
Configuring done
---
  but the command is never actually executed?  I go out to a command
line and type cmake . and the build goes.
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


Re: [CMake] [CPACK] Patch with componentwise extra install commands for NSIS-generator

2011-11-26 Thread Eric Noulard
2011/11/26 Marcel minusdreidb+cm...@gmail.com:
 Hi,

 I extended cpack's NSIS-generator and want to contribute the attached patch.

 It adds the CPACK_COMPONENT_name_EXTRA_INSTALL_COMMANDS option to cpack
 that allows to add NSIS commands exclusivly to the install section generated
 for the component name. So it adopts the option
 CPACK_NSIS_EXTRA_INSTALL_COMMANDS for single components/sections.

 That way special code can be added to a section that ist only executed if
 the user chooses to install the section.

 Perhaps this change could be merged into the cmake, because I think this
 could be of some use for other cpack users.

 If this is not the right place to contribute, could someone please give me a
 pointer.

Open a bug report in the tracker
http://public.kitware.com/Bug/my_view_page.php
and attach the patch to the report.



 Best regards,

 Marcel


 --

 Powered by www.kitware.com

 Visit other Kitware open-source projects at
 http://www.kitware.com/opensource/opensource.html

 Please keep messages on-topic and check the CMake FAQ at:
 http://www.cmake.org/Wiki/CMake_FAQ

 Follow this link to subscribe/unsubscribe:
 http://www.cmake.org/mailman/listinfo/cmake




-- 
Erk
Membre de l'April - « promouvoir et défendre le logiciel libre » -
http://www.april.org
--

Powered by www.kitware.com

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Follow this link to subscribe/unsubscribe:
http://www.cmake.org/mailman/listinfo/cmake


[Cmake-commits] CMake branch, master, updated. v2.8.6-276-g66f44dc

2011-11-26 Thread KWSys Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  66f44dcdf4ba725735d6e2023b79bbed4033c728 (commit)
  from  d63af6df7cceaa2c727490001b1ab0382b6c899c (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=66f44dcdf4ba725735d6e2023b79bbed4033c728
commit 66f44dcdf4ba725735d6e2023b79bbed4033c728
Author: KWSys Robot kwro...@kitware.com
AuthorDate: Sat Nov 26 00:05:08 2011 -0500
Commit: KWSys Robot kwro...@kitware.com
CommitDate: Sat Nov 26 00:05:08 2011 -0500

KWSys Nightly Date Stamp

diff --git a/Source/kwsys/kwsysDateStamp.cmake 
b/Source/kwsys/kwsysDateStamp.cmake
index 99fb16e..6ee8947 100644
--- a/Source/kwsys/kwsysDateStamp.cmake
+++ b/Source/kwsys/kwsysDateStamp.cmake
@@ -18,4 +18,4 @@ SET(KWSYS_DATE_STAMP_YEAR  2011)
 SET(KWSYS_DATE_STAMP_MONTH 11)
 
 # KWSys version date day component.  Format is DD.
-SET(KWSYS_DATE_STAMP_DAY   25)
+SET(KWSYS_DATE_STAMP_DAY   26)

---

Summary of changes:
 Source/kwsys/kwsysDateStamp.cmake |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v2.8.6-2028-ga95cfca

2011-11-26 Thread Stephen Kelly
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  a95cfcaa54507b7ab2c223a951d18ed3fc92ced1 (commit)
   via  a8286235a31437505a53f5874e8bf98524b6dca3 (commit)
   via  b8c8cab2428b10d5a1cb3af4ae72bc3c3f091f4d (commit)
  from  9e7fde55127cb2bd1e9ab52d97b43db09ad89a16 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a95cfcaa54507b7ab2c223a951d18ed3fc92ced1
commit a95cfcaa54507b7ab2c223a951d18ed3fc92ced1
Merge: 9e7fde5 a828623
Author: Stephen Kelly steve...@gmail.com
AuthorDate: Sat Nov 26 09:32:31 2011 -0500
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Sat Nov 26 09:32:31 2011 -0500

Merge topic 'automoc_qt5' into next

a828623 moc is now part of the Qt5Core module
b8c8cab Merge remote-tracking branch 'origin/master' into automoc_qt5


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a8286235a31437505a53f5874e8bf98524b6dca3
commit a8286235a31437505a53f5874e8bf98524b6dca3
Author: Stephen Kelly steve...@gmail.com
AuthorDate: Sat Nov 26 15:15:33 2011 +0100
Commit: Stephen Kelly steve...@gmail.com
CommitDate: Sat Nov 26 15:15:33 2011 +0100

moc is now part of the Qt5Core module

There is no separate SrcTools module anymore.

diff --git a/Modules/AutomocInfo.cmake.in b/Modules/AutomocInfo.cmake.in
index 8542ff6..2c7c724 100644
--- a/Modules/AutomocInfo.cmake.in
+++ b/Modules/AutomocInfo.cmake.in
@@ -11,5 +11,5 @@ set(AM_QT_MOC_EXECUTABLE @QT_MOC_EXECUTABLE@)
 set(AM_CMAKE_CURRENT_SOURCE_DIR @CMAKE_CURRENT_SOURCE_DIR@/)
 set(AM_CMAKE_CURRENT_BINARY_DIR @CMAKE_CURRENT_BINARY_DIR@/)
 set(AM_QT_VERSION_MAJOR @QT_VERSION_MAJOR@ )
-set(AM_Qt5SrcTools_VERSION_MAJOR @Qt5SrcTools_VERSION_MAJOR@ )
+set(AM_Qt5Core_VERSION_MAJOR @Qt5Core_VERSION_MAJOR@ )
 set(AM_TARGET_NAME @_moc_target_name@)
diff --git a/Source/cmQtAutomoc.cxx b/Source/cmQtAutomoc.cxx
index 7a80f28..d07f84b 100644
--- a/Source/cmQtAutomoc.cxx
+++ b/Source/cmQtAutomoc.cxx
@@ -49,11 +49,11 @@ void cmQtAutomoc::SetupAutomocTarget(cmTarget* target)
 {
   cmMakefile* makefile = target-GetMakefile();
   const char* targetName = target-GetName();
   // don't do anything if there is no Qt4 or Qt5SrcTools (which contains moc):
   std::string qtMajorVersion = makefile-GetSafeDefinition(QT_VERSION_MAJOR);
   if (qtMajorVersion == )
 {
-qtMajorVersion = makefile-GetSafeDefinition(Qt5SrcTools_VERSION_MAJOR);
+qtMajorVersion = makefile-GetSafeDefinition(Qt5Core_VERSION_MAJOR);
 }
   if (qtMajorVersion != 4  qtMajorVersion != 5)
 {
@@ -229,7 +229,7 @@ bool cmQtAutomoc::ReadAutomocInfoFile(cmMakefile* makefile,
   if (this-QtMajorVersion == )
 {
 this-QtMajorVersion = makefile-GetSafeDefinition(
- AM_Qt5SrcTools_VERSION_MAJOR);
+ AM_Qt5Core_VERSION_MAJOR);
 }
   this-Sources = makefile-GetSafeDefinition(AM_SOURCES);
   this-Headers = makefile-GetSafeDefinition(AM_HEADERS);

http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=b8c8cab2428b10d5a1cb3af4ae72bc3c3f091f4d
commit b8c8cab2428b10d5a1cb3af4ae72bc3c3f091f4d
Merge: bafe5cc 5675ec5
Author: Stephen Kelly steve...@gmail.com
AuthorDate: Thu Nov 10 15:46:13 2011 +0100
Commit: Stephen Kelly steve...@gmail.com
CommitDate: Thu Nov 10 15:46:13 2011 +0100

Merge remote-tracking branch 'origin/master' into automoc_qt5


---

Summary of changes:
 Modules/AutomocInfo.cmake.in |2 +-
@@ -49,11 +49,11 @@ void cmQtAutomoc::SetupAutomocTarget(cmTarget* target)
   cmMakefile* makefile = target-GetMakefile();
   const char* targetName = target-GetName();
-  // don't do anything if there is no Qt4 or Qt5SrcTools (which contains moc):
+  // don't do anything if there is no Qt4 or Qt5Core (which contains moc):
   std::string qtMajorVersion = makefile-GetSafeDefinition(QT_VERSION_MAJOR);
   if (qtMajorVersion == )
 Source/cmQtAutomoc.cxx   |6 +++---
 2 files changed, 4 insertions(+), 4 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/cgi-bin/mailman/listinfo/cmake-commits